@@ -16,11 +16,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
 name = "pyFIS"
-version = "1.4.0"
+version = "1.6.1"
 description = "A library for controlling devices in the passenger information realm"
 license = "GPLv3"
 author = "Julian Metzler"
 author_email = "git@mezgr.de"
 requires = ['pyserial']
 url = "https://github.com/Mezgrman/pyFIS"
-keywords = "led sign message board effect library wrapper serial text display ibis vdv300 bus next stop train mono lawo splitflap"
\ No newline at end of file
+keywords = "led sign message board effect library wrapper serial text display ibis vdv300 bus next stop train mono lawo splitflap industrial factory"
\ No newline at end of file
